.. currentmodule:: brainsets

brainsets.taxonomy
------------------

.. autoclass:: brainsets.taxonomy.Species
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.taxonomy.Sex
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.taxonomy.RecordingTech
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.taxonomy.Hemisphere
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.taxonomy.Channel
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.taxonomy.Probe
    :members:
    :show-inheritance:
    :undoc-members:

.. autoclass:: brainsets.taxonomy.Macaque
    :members:
    :show-inheritance:
    :undoc-members:
